import netifaces as ni
import os


def getIpV4():
    if os.name == 'nt':
        raise Exception("This module not support windows")
    iface = ni.interfaces()
    def inner_get_ip(key):
        adr = ni.ifaddresses(key)
        if ni.AF_INET in adr:
            return adr[ni.AF_INET][0]['addr']
        return None
    desirdIface = ['eth0', 'wlan0']
    for i in desirdIface:
        _ipv4 = inner_get_ip(i)
        if _ipv4 is not None:
            return i, _ipv4
    return None, None



from setuptools import setup, find_packages

VERSION = "2.1.0"

install_requires = [
    'pyserial',
    'paho-mqtt',
    'websocket-client',
]

setup(
    name="vmipy",
    version=VERSION,
    description="SDK for vmilabs",
    long_description=open("README.md").read(),
    long_description_content_type='text/markdown',
    author="vmilabs",
    author_email="zeekzhou@163.com",
    license="Apache-2.0",
    url="https://github.com/openvmi/vmipy",
    python_requires='>=3.6',
    keywords="vmilabs python SDK",
    install_requires=install_requires,
    packages=find_packages('src'),
    package_dir={'': 'src'},
)
